@@ -3,8 +3,9 @@
 
 import logging
 import smtplib
-from email.message import EmailMessage
-from email.utils import make_msgid
+
+from mailer import Mailer
+from mailer import Message
 
 class SMTP(object):
     """SMTP class."""
@@ -14,35 +15,25 @@ class SMTP(object):
         self.server = server
         self.verbose = verbose
 
-        # smtplib package
-        self.smtplib = smtplib
-
         # attempt to connect to SMTP server
         try:
-            self.smtp = smtplib.SMTP(self.server)
+            self.smtp = Mailer(self.server)
         except smtplib.SMTPException as e:
             print('ERROR connecting to SMTP server: %s' % (self.server))
             print(e)
 
     def send(self, to, frm, subject, body, attachment=None):
         """Send an email message."""
-        # create the message string
-        msg = EmailMessage()
-        msg['Subject'] = subject
-        msg['From'] = frm
-        msg['To'] = to
-        msg.set_content(body)
+        msg = Message(From=frm, To=to)
+        msg.Subject = subject
+        msg.Html = body
 
         if attachment:
-            with open(attachment, 'rb') as fp:
-                data = fp.read()
-                ctype = 'application/octet-stream'
-                maintype, subtype = ctype.split('/', 1)
-                msg.add_attachment(data, maintype=maintype, subtype=subtype, filename=attachment)
+            msg.attach(attachment)
 
         # attempt to send the message
         try:
-            self.smtp.send_message(msg)
+            self.smtp.send(msg)
             return True
         except smtplib.SMTPException as e:
             logging.error('ERROR sending email to: %s: %s', to, e)
